@@ -1,12 +1,12 @@
 """
 Command Line Options
 """
-
+from _pytest.config.argparsing import Parser
 
 HELP_TEXT = "set base dir for getting CSV data files from"
 
 
-def pytest_addoption(parser, plugin_name="csv-params"):
+def pytest_addoption(parser: Parser, plugin_name: str = "csv-params") -> None:
     """
     Add Command Line Arguments for pytest execution
     """
