@@ -2,6 +2,7 @@
 The main Plugin implementation
 """
 
+from _pytest.config import Config
 
 BASE_DIR_KEY = "__pytest_csv_plugins__config__base_dir"
 
@@ -11,7 +12,7 @@ class Plugin:  # pylint: disable=too-few-public-methods
     Plugin Class
     """
 
-    def __init__(self, config):
+    def __init__(self, config: Config) -> None:
         """
         Hold the pytest config
         """
