@@ -2,12 +2,11 @@
 Types to ease the usage of the API
 """
 import csv
-from typing import Callable, Dict, Optional, Type, TypeVar
+from typing import Any, Callable, Dict, Optional, Type
 
-T = TypeVar("T")
-
-DataCast = Callable[[str], T]
+DataCast = Callable[[str], Any]
 DataCastDict = Dict[str, DataCast]
+DataCasts = Optional[DataCastDict]
 
 BaseDir = Optional[str]
 IdColName = Optional[str]
